@@ -2,7 +2,6 @@
 Data Conversion utility methods for handling assessment data transformations.
 
 """
-import six
 
 
 def update_training_example_answer_format(answer):
@@ -14,7 +13,7 @@ def update_training_example_answer_format(answer):
     Returns:
         dict
     """
-    if isinstance(answer, (str, six.text_type)):
+    if isinstance(answer, str):
         return {
             'parts': [
                 {'text': answer}
